#include "i2cfunc.h"

/*******************************************************************
  Beschreibung: I2C Start Routine
  Parameter: IC-Adresse und Modus (Read = 1 oder Write = 0)
  Returns: Nichts
********************************************************************/
void i2c_start(uint8_t IC,uint8_t rw)
{
  uint8_t addr_byte = 0;

  //I2C initialisieren, TWBR = 3 -> SCL freq = 100kHz
  TWBR = 3;	
  //Sende Start Condition		
  TWCR = (1<<TWINT) | (1<<TWSTA) | (1<<TWEN); 
   
  //Warte bis bertragung beendet ist
  //while(!(TWCR & (1<<TWINT)));// setzt TWINT-bit im TWCR-bytes   
  
  //addr_byte = adress und um 1 bit nach links verschieben (fr r/w bit)
  addr_byte = (IC << 1);    
  //R/W-bit hinzufgen
  addr_byte |= rw;	

  //Adresse senden
  TWDR = addr_byte;	  
  //Clear TWINT bit in TWCR to start transmission of address
  TWCR = (1 << TWINT) | (1 << TWEN);	
  
  //Warte bis bertragung beendet ist	
  //while(!(TWCR & (1 << TWINT)));	
}

/*******************************************************************
  Beschreibung: I2C Sende Routine
  Parameter: zu bertragender Wert/Variable
  Returns: Nichts
********************************************************************/
void i2c_send(uint8_t data)
{
  TWDR = data;	
  //Daten senden
  //Clear TWINT bit in TWCR to start transmission of data
  TWCR = (1 << TWINT) | (1 << TWEN);	
  
  //Warte bis bertragung beendet ist
  //while(!(TWCR & (1 << TWINT)));		
}

/*******************************************************************
  Beschreibung: I2C Lese Routine
  Parameter: Nichts
  Returns: TWDR Inhalt, Adresse oder Datum
********************************************************************/
uint8_t i2c_read (void)
{
  //send content of TWDR; TWEA = enable ACK
  TWCR = (1<<TWINT) | (1<<TWEA) | (1<<TWEN);
  	
  //wait, until byte has been received --> ACK
  //while(!(TWCR & (1 << TWINT)));

  BSP_ToggleLed(LED_YELLOW);
  return TWDR;
}

/*******************************************************************
  Beschreibung: I2C Stop Routine, macht den Bus frei
  Parameter: Nichts
  Returns: Nichts
********************************************************************/
void i2c_stop(void) 
{
  //Sende Stop-Condition
  TWCR= (1<<TWINT) | (1<<TWSTO) | (1<<TWEN);
 
  //Warte bis bertragung beendet ist, bis TWSTO-bit gesetzt ist
  //while(!(TWCR & (1 << TWSTO)));
}

/*******************************************************************
  Beschreibung: Aktiviert den Pegelwandler um I2c Funktion zu Gewhrleisten
  Parameter: Nichts
  Returns: Nichts
********************************************************************/
void PConv(void)
{ 
  uint8_t level;
  GPIO_7_make_out();
  level = GPIO_7_read();
  if(1 != level) // Prfung ob der Pegelwandler bereits aktiv ist
    GPIO_7_set(); // Noch nicht aktiv -> setzte Bit zum aktivieren
}

/*******************************************************************
  Beschreibung: Warteschleife
  Parameter: Nichts
  Returns: Nichts
********************************************************************/
void wait(void)
{
  int i, j;
  //delay
  for (i=0; i<20000; i++)
  {			
    for (j=0; j<10; j++) 
	{
	  asm volatile ("nop");
	}
  }
}

//eof i2cfunc.c
