#include "throughputTest.h"
#include <avr/io.h>
#include <stdlib.h>

// Set APP_PAYLOAD_SIZE to maximum possible if not specified before
#ifndef APP_PAYLOAD_SIZE
#define APP_PAYLOAD_SIZE APS_MAX_ASDU_SIZE
#endif

static APS_DataReq_t  msgParams; // Request parameters for APS_DataReq primitive
static void APS_DataConfRouter(APS_DataConf_t *confInfo); // Indication for data confirm on router

/********************************************************************
  Description: Process router or end device functionality.
               The function should be called only one time 
               after starting network.  
  Parameters: none.
  Returns: nothing.
********************************************************************/
void appRouterTaskHandler(void)
{
  static uint8_t buf[APS_ASDU_OFFSET + 1];

  PConv();
  
  i2c_start( VTI,WRITE );
  i2c_send( VTIMSB ); // VTIMSB = 0x7F
  i2c_start( VTI, READ );
  buf[APS_ASDU_OFFSET] = ~i2c_read(); // hole 8bit vom DATARD8 Register
	
  // Set data request parameters?
  msgParams.dstAddrMode             = APS_SHORT_ADDRESS; // Short (NWK) addressing is used
  msgParams.dstAddress.shortAddress = 0; // Coordinator NWK address is always 0
  msgParams.dstEndpoint             = END_POINT; // Destination application end point
  msgParams.profileId               = endpointParams.simpleDescriptor->AppProfileId; // Application Profile ID
  msgParams.clusterId               = 1; // Message Cluster ID (same for all messages)
  msgParams.srcEndpoint             = END_POINT; // Source end point address
  msgParams.asduLength              = APP_PAYLOAD_SIZE; // ASDU length 
  msgParams.asdu                    = (uint8_t *)(&buf[APS_ASDU_OFFSET]); // Buffer to ASDU
  msgParams.txOptions.acknowledgedTransmission = APP_USE_APS_ACK; // Flag indicating to use acknowledgements on APS layer or not
  msgParams.radius                  = 0;
  msgParams.APS_DataConf            = APS_DataConfRouter; // Confirm callback
 
  APS_DataReq(&msgParams);  // Send data request
  i2c_stop();  
}

/********************************************************************
  Description: Confirm on message transmission  
  Parameters: confInfo - confirmation information
  Returns: nothing.
********************************************************************/
static void APS_DataConfRouter(APS_DataConf_t *confInfo)
{ 
  if (APS_SUCCESS_STATUS == confInfo->status)
  {
    BSP_ToggleLed(DATA_TX_LED); // Indicate if successfull
  } 
  appRouterTaskHandler(); 
}

//eof thrTestRouter.c
